//
// JTypist v3.1 - Java typing tutor program for UNIX systems
// Copyright (C) 1998  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// ExerciseGUIStats class - creates a dialog with lesson completion
// statistics displayed
//
import java.awt.*;
import java.awt.event.*;
import java.applet.*;

/**
 * A dialog for lesson completion statistics.
 */
public class ExerciseGUIStats extends Dialog
		implements ActionListener, WindowListener {
	private boolean inAnApplet = true;

	// GUI components
	private Label		lesson_label;
	private Label		stats_line_1;
	private Label		stats_line_2;
	private Button		ok_button;
	private Frame		parent;

	/**
	 * Initialize the whole GUI set.
	 */
	public ExerciseGUIStats( boolean inAnApplet, Frame frame,
			boolean flag ) {
		super( frame, flag );
		this.addWindowListener( this );
		parent		= frame;
		this.inAnApplet	= inAnApplet;

		// create GUI components
		setTitle( "Typist v3.1 Exercise Timings" );
		setLayout( new BorderLayout() );

		// create the labels
		Panel label_panel = new Panel();
		label_panel.setLayout( new GridLayout( 0, 1 ));
		lesson_label = new Label();
		label_panel.add( lesson_label );
		stats_line_1 = new Label();
		label_panel.add( stats_line_1 );
		stats_line_2 = new Label();
		label_panel.add( stats_line_2 );
		add( "Center", label_panel );

		Panel button_panel = new Panel();
		button_panel.setLayout( new FlowLayout() );
		ok_button = new Button( "OK" );
		ok_button.addActionListener( this );
		button_panel.add ( ok_button );
		add( "South", button_panel );
	}


	/**
	 * Show a specific single set of statistics for a specific lesson.
	 */
	public void reveal( ExerciseLesson lesson,
			KeyingStatistics keying_stats ) {

		// update the labels with the details passed in
		lesson_label.setText( "Exercise '" + lesson.get_title()
				+ "' completed:" );
		int total_keystrokes = keying_stats.get_strikes()
				+ keying_stats.get_misses();
		stats_line_1.setText( "You made "
			+ total_keystrokes + " timed keystrokes, with "
			+ keying_stats.get_pc_accuracy() + "% accuracy" );
		stats_line_2.setText( "Your speed was "
			+ keying_stats.get_WPM( false ) + " WPM, "
			+ keying_stats.get_WPM( true ) + " WPM adjusted " );

		// call pack to resize the dialog box, then render
		pack(); setVisible( true );
		ok_button.requestFocus();
	}


	/*
	 * Handle dismiss, close, etc by just hiding ourselves.
	 */
	private void handle_ok_button() {

		// simply just hide this frame from view
		setVisible( false );
	}


	/*
	 * Handle GUI component actions and events.
	 */
	public void actionPerformed( ActionEvent evt ) {
		if ( evt.getSource() instanceof Button ) {
			if ( evt.getSource() == ok_button ) {
				handle_ok_button();
			}
		}
	}
	public void windowClosing( WindowEvent evt ) {
		handle_ok_button();
	}
	public void windowClosed( WindowEvent evt ) {}
	public void windowOpened( WindowEvent evt ) {}
	public void windowIconified( WindowEvent evt ) {}
	public void windowDeiconified( WindowEvent evt ) {}
	public void windowActivated( WindowEvent evt ) {}
	public void windowDeactivated( WindowEvent evt ) {}


	/**
	 * Class test code.
	 */
	public static void main( String args[] ) {
		System.out.println( "*** CLASS TEST CODE ***" );
		Frame frame = new Frame();
		frame.setSize( 100, 100 );
		frame.setVisible( true );
		ExerciseGUIStats stats = new ExerciseGUIStats( false, frame,
				false );
		stats.pack();
		KeyingStatistics s = new KeyingStatistics();
		s.struck( 300 ); s.struck( 200 ); s.struck( 100 );
		s.missed( 400 );
		stats.reveal( new DrillLesson( "Test lesson", "", "" ), s );
	}
}
