//
// JTypist v3.1 - Java typing tutor program for UNIX systems
// Copyright (C) 1998  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// Gauge class - implements a Windows-style gauge GUI component
//
import java.applet.*;
import java.awt.*;

/**
 * Implements a Windows-style gauge GUI component.
 */
public class Gauge extends Canvas {

	// the gauge current value, range, units, and preferred size
	private int		range_min	= 0;
	private int		range_max	= 100;
	private int		value		= 0;
	private String		units		= "%";
	private Dimension	pref_size	= new Dimension( 40, 18 );


	/**
	 * Create a gauge with default range, value, and units.
	 */
	public Gauge() {}

	/**
	 * Create a gauge with specified range, value, and units.
	 */
	public Gauge( int range_min, int range_max, int value, String units ) {
		this.range_min	= range_min;
		this.range_max	= range_max;
		this.value	= value;
		this.units	= units;
	}

	/*
	 * Return dimensions.
	 */
	public Dimension getpreferredSize()	{ return ( pref_size ); }
	public Dimension getminimumSize()	{ return ( pref_size ); }

	/**
	 * Paint the graphic; here, we use update to render all of the
	 * graphic, and just call it from paint - this is a bit of an
	 * abuse of the architecture, but the one thing it does stop is the
	 * complete clearing of the graphic as done with the default update.
	 * The thing is, we can't really do a meaningful update, so the
	 * update has to repaint just about every pixel.  Thus, we can get
	 * away with reusing update to do paint.
	 */
	public void paint( Graphics g ) { update( g ); }

	/**
	 * Paint the graphic.
	 */
	public void update( Graphics g ) {
		Dimension d = getSize();

		// calculate the fill width, and reset its bounds if
		// it could be outside the allowed area
		int fill_width = (( d.width - 4 ) * ( value - range_min ))
					/ ( range_max - range_min );
		if ( fill_width < 0 )
			fill_width = 0;
		else if ( fill_width > d.width - 4 )
			fill_width = d.width - 4;

		// plot in the gauge value
		g.setColor( getForeground() );
		g.fillRect( 2, 2, fill_width, d.height - 4 );
		g.setColor( getBackground() );
		g.fillRect( fill_width + 1, 2, d.width - 4, d.height - 4 );

		// write the numeric value centrally in the gauge
		FontMetrics fm	= g.getFontMetrics();
		String svalue	= Integer.toString( value ) + units;
		// g.setXORMode( Color.black );
		g.setColor( Color.white );
		g.drawString( svalue,
				( d.width - fm.stringWidth( svalue )) / 2,
				( d.height + fm.getAscent() ) / 2 );
		// g.setPaintMode();

		// end with a small box round the gauge canvas
		g.setColor( getBackground() );
		g.draw3DRect( 0, 0, d.width - 1, d.height - 1, false );
		// g.drawRect( 2, 2, d.width - 3, d.height - 3 );
	}


	/*
	 * Standard get/set methods.
	 */
	public int	get_min()	{ return ( range_min ); }
	public int	get_max()	{ return ( range_max ); }
	public int	get_value()	{ return ( value ); }
	public String	get_units()	{ return ( units ); }
	public void set_min( int range_min ) {
		if ( range_min != this.range_min ) {
			this.range_min = range_min; repaint();
		}
	}
	public void set_max( int range_max ) {
		if ( range_max != this.range_max ) {
			this.range_max = range_max; repaint();
		}
	}
	public void set_value( int value ) {
		if ( value != this.value ) {
			this.value = value; repaint();
		}
	}
	public void set_units( String units ) {
		if ( units != this.units ) {
			this.units = units; repaint();
		}
	}


	/**
	 * Class test code.
	 */
	public static void main( String args[] ) {
		System.out.println( "*** CLASS TEST CODE ***" );

		Frame frame = new Frame();
		Gauge gauge = new Gauge();
		gauge.setForeground( Color.red );
		frame.setLayout( new BorderLayout() );
		frame.add( "Center", gauge );
		frame.pack(); frame.setVisible( true );
		for ( int i = -10; i <= 110; i++ ) {
			gauge.set_value( i );
			try { Thread.sleep( 100 ); }
			catch( InterruptedException e ) {}
		}
	}
}
