//
// JTypist v3.1 - Java typing tutor program for UNIX systems
// Copyright (C) 1998  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// HelpHTML class - glom of stuff to print online help as HTML
//

/**
 * Glom of stuff to print online help as HTML.
 */
abstract public class HelpHTML {

	// string full of GNU GPL header
	private static final String GNUGPL =
  "<!--\n"
+ "  -- JTypist v3.1 - Java typing tutor program for UNIX system\n"
+ "  -- Copyright (C) 1998  Simon Baldwin (simonb@sco.com)\n"
+ "  --\n"
+ "  -- This program is free software; you can redistribute it and/or\n"
+ "  -- modify it under the terms of the GNU General Public License\n"
+ "  -- as published by the Free Software Foundation; either version 2\n"
+ "  -- of the License, or (at your option) any later version.\n"
+ "  --\n"
+ "  -- This program is distributed in the hope that it will be useful,\n"
+ "  -- but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
+ "  -- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+ "  -- GNU General Public License for more details.\n"
+ "  --\n"
+ "  -- You should have received a copy of the GNU General Public License\n"
+ "  -- along with this program; if not, write to the Free Software\n"
+ "  -- Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n"
+ "  --\n"
+ "  --  -->\n";


	/*
	 * Convenience functions to find topic_name and topic_text
	 * from a help topic string.
	 */
	private static String get_topic_name( String s ) {
		return ( s.substring( 0, s.indexOf( "\n" )));
	}
	private static String get_topic_text( String s ) {
		return ( s.substring( s.indexOf( "\n" ) + 1, s.length() ));
	}


	/**
	 * Print out a help text array as an HTML document.
	 */
	public static String toHTML( String help_text[] ) {
		StringBuffer buffer = new StringBuffer();

		// write out the HTML header
		buffer.append( "<HTML>\n" );
		buffer.append( GNUGPL );
		buffer.append( "<HEAD>\n" );
		buffer.append( "<TITLE>Typist v3.1 (Java) User's Guide</TITLE>\n" );
		buffer.append( "</HEAD>\n<BODY BGCOLOR=\"#FFFFFF\">\n" );
		buffer.append( "<H1>Typist v3.1 (Java) User's Guide</H1>\n" );
		buffer.append( "<P>\n\n" );

		// write out a contents section
		buffer.append( "<H2>Table Of Contents</H2>\n" );
		buffer.append( "<P>\n\n" );
		buffer.append( "This document contains the following sections:\n" );
		buffer.append( "<OL>\n" );
		for ( int index = 0; index < help_text.length; index++ )
			buffer.append( "<LI><A HREF=\"#topic_" + index + "\">"
					+ get_topic_name( help_text[ index ])
					+ "</A></LI>\n" );
		buffer.append( "</OL>\n<P>\n\n" );

		// write out each topic from the help array
		for ( int index = 0; index < help_text.length; index++ ) {
			buffer.append( "<H2><A NAME=\"topic_" + index + "\">"
					+ get_topic_name( help_text[ index ])
					+ "</A></H2>\n" );
			buffer.append( "<P>\n\n" );
			buffer.append( get_topic_text( help_text[ index ] ) );
			buffer.append( "<P>\n\n" );
		}

		// finish up
		buffer.append( "</BODY>\n</HTML>\n" );
		return ( buffer.toString() );
	}


	/**
	 * Prints out the HelpText class' data attribute as HTML.
	 */
	public static void main( String args[] ) {
		System.out.println( toHTML( HelpText.data ));
	}
}
