//
// JTypist v3.1 - Java typing tutor program for UNIX systems
// Copyright (C) 1998  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// TutorialGUI class - creates a frame to display a tutorial
//
import java.awt.*;
import java.awt.event.*;
import java.applet.*;

/**
 * Creates a frame to display a tutorial.
 */
public class TutorialGUI extends Frame
		implements ActionListener, WindowListener {
	private boolean inAnApplet = true;

	// menubar GUI components
	private MenuBar		menu_bar;
	private Menu		file_menu, help_menu;
	private MenuItem	file_close;

	// GUI components
	private Label		title_label;
	private TextArea	text_area;

	/**
	 * Initialize the whole GUI set.
	 */
	public TutorialGUI( boolean inAnApplet ) {
		this.addWindowListener( this );
		this.inAnApplet = inAnApplet;

		// create GUI components
		setTitle( "Typist v3.1 Tutorial Window" );
		setLayout( new BorderLayout() );

		// create the menu bar stuff
		menu_bar = new MenuBar();
		setMenuBar( menu_bar );
		// File menu
		file_menu = new Menu( "File" );
		menu_bar.add( file_menu );
		file_close = new MenuItem( "Close window",
				new MenuShortcut( KeyEvent.VK_C ));
		file_close.addActionListener( this );
		file_menu.add( file_close );

		// create the label and text display
		title_label = new Label();
		add( "North", title_label );

		text_area = new TextArea( 12, 80 );
		text_area.setBackground( Color.white );
		text_area.setEditable( false );
		add( "Center", text_area );
	}


	/**
	 * Display the tutorial text from a lesson passed in.
	 */
	public void reveal( TutorialLesson lesson ) {

		// set up the title label and text area
		title_label.setText( lesson.get_title() );
		text_area.setText( lesson.get_text() );
		setVisible( true );
	}

	/*
	 * Handle dismiss, close, etc by just hiding ourselves.
	 */
	private void handle_close_button() {

		// simply just hide this frame from view
		setVisible( false );
	}


	/*
	 * Handle GUI component actions and events.
	 */
	public void actionPerformed( ActionEvent evt ) {
		if ( evt.getSource() instanceof MenuItem ) {
			if ( evt.getSource() == file_close ) {
				handle_close_button();
			}
		}
	}
	public void windowClosing( WindowEvent evt ) {
		handle_close_button();
	}
	public void windowClosed( WindowEvent evt ) {}
	public void windowOpened( WindowEvent evt ) {}
	public void windowIconified( WindowEvent evt ) {}
	public void windowDeiconified( WindowEvent evt ) {}
	public void windowActivated( WindowEvent evt ) {}
	public void windowDeactivated( WindowEvent evt ) {}


	/**
	 * Class test code.
	 */
	public static void main( String args[] ) {
		System.out.println( "*** CLASS TEST CODE ***" );

		TutorialGUI tutorial = new TutorialGUI( false );
		tutorial.pack();
		tutorial.reveal( new TutorialLesson ( "Test lesson title",
			"This is test text for a tutorial window" ));
	}
}
